@@ -96,7 +96,7 @@ def _find(api_method, query, limit, return_handler, first_page_size, **kwargs):
 
         for i in resp["results"]:
             if num_results == limit:
-                raise StopIteration()
+                return
             num_results += 1
             yield format_result(i)
 
@@ -105,7 +105,7 @@ def _find(api_method, query, limit, return_handler, first_page_size, **kwargs):
             query["starting"] = resp["next"]
             query["limit"] = min(query["limit"]*2, 1000)
         else:
-            raise StopIteration()
+            return
 
 def find_data_objects(classname=None, state=None, visibility=None,
                       name=None, name_mode='exact', properties=None,
@@ -119,7 +119,7 @@ def find_data_objects(classname=None, state=None, visibility=None,
     """
     :param classname:
         Class with which to restrict the search, i.e. one of "record",
-        "file", "gtable", "applet", "workflow"
+        "file", "applet", "workflow", "database"
     :type classname: string
     :param state: State of the object ("open", "closing", "closed", "any")
     :type state: string
@@ -191,11 +191,11 @@ def find_data_objects(classname=None, state=None, visibility=None,
            items1 = list(find_data_objects(created_before="-1w"))
            items2 = list(find_data_objects(created_before=-7*24*60*60*1000))
 
-    This example iterates through all GenomicTables with property
-    "project" set to "cancer project" and prints their object IDs::
+    This example iterates through all files with property
+    "project" set to "cancer project" and prints their object IDs:
 
-      for result in find_data_objects(classname="gtable", properties={"project": "cancer project"}):
-          print "Found gtable with object id " + result["id"]
+      for result in find_data_objects(classname="file", properties={"project": "cancer project"}):
+          print "Found a file with object id " + result["id"]
 
     """
 
@@ -445,6 +445,7 @@ def find_projects(name=None, name_mode='exact', properties=None, tags=None,
     :param tags: Tags that each result must have
     :type tags: list of strings
     :param level: One of "VIEW", "UPLOAD", "CONTRIBUTE", or "ADMINSTER". If specified, only returns projects where the current user has at least the specified permission level.
+        If not specified the default value is "CONTRIBUTE" for the API method /system/findProjects
     :type level: string
     :param describe: Controls whether to also return the output of
         calling describe() on each project. Supply False to omit
@@ -663,19 +664,16 @@ def find_global_workflows(name=None, name_mode='exact', category=None,
 def _find_one(method, zero_ok=False, more_ok=True, **kwargs):
     kwargs["limit"] = 1 if more_ok else 2
     response = method(**kwargs)
-    try:
-        result = next(response)
-        if not more_ok:
-            try:
-                next(response)
-                raise DXSearchError("Expected one result, but found more: "+str(kwargs))
-            except StopIteration:
-                pass
-    except StopIteration:
+    result = next(response, None)
+    if result is None:
         if zero_ok:
             return None
         else:
             raise DXSearchError("Expected one result, but found none: "+str(kwargs))
+    if not more_ok:
+        result2 = next(response, None)
+        if result2 is not None:
+            raise DXSearchError("Expected one result, but found more: "+str(kwargs))
     return result
 
 
