@@ -34,7 +34,7 @@ class DXError(Exception):
 class DXAPIError(DXError):
     '''
     Exception for when the API server responds with a code that is not 200 (OK). See
-    https://wiki.dnanexus.com/API-Specification-v1.0.0/Protocols#Errors for complete documentation of API errors,
+    https://documentation.dnanexus.com/developer/api/protocols#errors for complete documentation of API errors,
     including those reflected by subclasses of this class.
     '''
     def __init__(self, content, code, timestamp="", req_id=""):
@@ -108,9 +108,6 @@ class DXPartLengthMismatchError(DXFileError):
 class DXChecksumMismatchError(DXFileError):
     '''Exception raised by :class:`dxpy.bindings.dxfile.DXFile` on checksum mismatch.'''
 
-class DXGTableError(DXError):
-    '''Exception for :class:`dxpy.bindings.dxgtable.DXGTable`.'''
-
 class DXSearchError(DXError):
     '''Exception for :mod:`dxpy.bindings.search` methods.'''
 
@@ -223,6 +220,7 @@ def exit_with_exc_info(code=1, message='', print_tb=False, exception=None):
     sys.exit(code)
 
 network_exceptions = (requests.packages.urllib3.exceptions.ProtocolError,
+                      requests.packages.urllib3.exceptions.NewConnectionError,
                       requests.packages.urllib3.exceptions.DecodeError,
                       requests.packages.urllib3.exceptions.ConnectTimeoutError,
                       requests.packages.urllib3.exceptions.ReadTimeoutError,
@@ -258,7 +256,7 @@ def err_exit(message='', code=None, expected_exceptions=default_expected_excepti
 
     exc = exception if exception is not None else sys.exc_info()[1]
     if isinstance(exc, SystemExit):
-        raise
+        raise exc
     elif isinstance(exc, expected_exceptions):
         exit_with_exc_info(EXPECTED_ERR_EXIT_STATUS, message, print_tb=dxpy._DEBUG > 0, exception=exception)
     elif ignore_sigpipe and isinstance(exc, IOError) and getattr(exc, 'errno', None) == errno.EPIPE:
